@@ -46,12 +46,17 @@ import os
 from typing import Optional, Callable, Tuple, Union, List, Iterable, Dict
 
 from debian.changelog import Version
-from debian.deb822 import Deb822
 import subprocess
 import warnings
 
 from ._deb822 import PkgRelation
-from .deb822 import Deb822Editor, ChangeConflict
+from .deb822 import (
+    Deb822Editor,
+    ChangeConflict,
+    Deb822Paragraph,
+    new_deb822_paragraph,
+    parse_deb822_paragraph,
+    )
 from .reformatting import GeneratedFile
 
 
@@ -120,7 +125,7 @@ def guess_template_type(template_path: str) -> Optional[str]:
             elif b'@lintian-brush-test@' in template:
                 return 'lintian-brush-test'
             else:
-                deb822 = Deb822(template)
+                deb822 = parse_deb822_paragraph(template)
                 build_depends = deb822.get('Build-Depends', '')
                 if any(iter_relations(build_depends, 'gnome-pkg-tools')):
                     return 'gnome'
@@ -161,11 +166,35 @@ def _cdbs_resolve_conflict(
         actual_new_value)
 
 
-def _update_control_template(template_path: str, path: str, changes):
+def _expand_control_template(
+        template_path: str, path: str, template_type: str):
     package_root = os.path.dirname(os.path.dirname(path)) or '.'
+    if template_type == 'rules':
+        subprocess.check_call(
+            ['./debian/rules', 'debian/control'],
+            cwd=package_root)
+    elif template_type == 'gnome':
+        dh_gnome_clean(package_root)
+    elif template_type == 'postgresql':
+        pg_buildext_updatecontrol(package_root)
+    elif template_type == 'lintian-brush-test':
+        with open(template_path, 'rb') as inf, open(path, 'wb') as outf:
+            outf.write(
+                inf.read().replace(b'@lintian-brush-test@', b'testvalue'))
+    elif template_type == 'directory':
+        raise GeneratedFile(path, template_path)
+    else:
+        raise AssertionError
+
+
+def _update_control_template(
+        template_path: str, path: str, changes, expand_template=True):
     template_type = guess_template_type(template_path)
     if template_type is None:
         raise GeneratedFile(path, template_path)
+    if template_type == 'directory':
+        # We can't handle these yet
+        raise GeneratedFile(path, template_path)
     with Deb822Editor(template_path) as updater:
         resolve_conflict: Optional[Callable[[
             str, str, Optional[str], Optional[str], Optional[str]],
@@ -178,25 +207,13 @@ def _update_control_template(template_path: str, path: str, changes):
     if not updater.changed:
         # A bit odd, since there were changes to the output file. Anyway.
         return False
-    if template_type == 'rules':
-        subprocess.check_call(
-            ['./debian/rules', 'debian/control'],
-            cwd=package_root)
-    elif template_type == 'cdbs':
-        with Deb822Editor(path, allow_generated=True) as updater:
-            updater.apply_changes(changes)
-    elif template_type == 'gnome':
-        dh_gnome_clean(package_root)
-    elif template_type == 'postgresql':
-        pg_buildext_updatecontrol(package_root)
-    elif template_type == 'lintian-brush-test':
-        with open(template_path, 'rb') as inf, open(path, 'wb') as outf:
-            outf.write(
-                inf.read().replace(b'@lintian-brush-test@', b'testvalue'))
-    elif template_type == 'directory':
-        raise GeneratedFile(path, template_path)
-    else:
-        raise AssertionError
+
+    if expand_template:
+        if template_type == 'cdbs':
+            with Deb822Editor(path, allow_generated=True) as updater:
+                updater.apply_changes(changes)
+        else:
+            _expand_control_template(template_path, path, template_type)
     return True
 
 
@@ -214,8 +231,10 @@ def _preserve_field_order_preferences(paragraphs):
             continue
         if para['Package'] not in description_is_not_last:
             # Make sure Description stays the last field
-            para._Deb822Dict__keys.add('Description')
-            para._Deb822Dict__keys.remove('Description')
+            try:
+                para.order_last('Description')
+            except KeyError:
+                pass  # it's okay if the field doesn't exist
 
 
 def update_control(path='debian/control', source_package_cb=None,
@@ -234,6 +253,14 @@ def update_control(path='debian/control', source_package_cb=None,
     return updater.changed
 
 
+def _find_template_path(path):
+    for template_path in [path + '.in', path + '.m4']:
+        if os.path.exists(template_path):
+            return template_path
+    else:
+        return None
+
+
 class ControlEditor(object):
     """Edit a control file.
     """
@@ -247,6 +274,7 @@ class ControlEditor(object):
         self._primary = Deb822Editor(
             path, allow_reformatting=allow_reformatting,
             allow_missing=allow_missing)
+        self._template_only = False
 
     @classmethod
     def create(cls, path: str = 'debian/control'):
@@ -260,22 +288,28 @@ class ControlEditor(object):
         return cls(tree.abspath(relpath))
 
     @property
-    def paragraphs(self) -> List[Deb822]:
+    def paragraphs(self) -> List[Deb822Paragraph]:
         """List of all the paragraphs."""
         return self._primary.paragraphs
 
     @property
-    def source(self) -> Deb822:
+    def source(self) -> Deb822Paragraph:
         """Source package."""
-        if (len(self.paragraphs[0]) > 0 and
-                not self.paragraphs[0].get('Source')):
-            raise ValueError('first paragraph is not Source')
-        return self.paragraphs[0]
+        for entry in self.paragraphs:
+            if not entry.get('Source'):
+                raise ValueError('first paragraph is not Source')
+            return entry
+        else:
+            p = new_deb822_paragraph()
+            self.paragraphs.insert(0, p)
+            return p
 
     @property
-    def binaries(self) -> List[Deb822]:
+    def binaries(self) -> Iterable[Deb822Paragraph]:
         """List of binary packages."""
-        return self._primary.paragraphs[1:]
+        for entry in self.paragraphs:
+            if entry.get('Package'):
+                yield entry
 
     def changes(self):
         """Return a dictionary describing the changes since the base.
@@ -314,7 +348,20 @@ class ControlEditor(object):
         return changes
 
     def __enter__(self):
-        self._primary.__enter__()
+        try:
+            self._primary.__enter__()
+        except FileNotFoundError:
+            template_path = _find_template_path(self.path)
+            if template_path:
+                self._template_only = True
+                template_type = guess_template_type(template_path)
+                if template_type is None:
+                    raise GeneratedFile(self.path, template_path)
+                _expand_control_template(
+                    template_path, self.path, template_type)
+                self._primary.__enter__()
+            else:
+                raise
         self._field_order_preserver = _preserve_field_order_preferences(
             self._primary.paragraphs)
         self._field_order_preserver.__enter__()
@@ -323,6 +370,9 @@ class ControlEditor(object):
     def __exit__(self, exc_type, exc_val, exc_tb):
         self._field_order_preserver.__exit__(exc_type, exc_val, exc_tb)
         try:
+            if self._template_only:
+                os.unlink(self.path)
+                raise FileNotFoundError
             self._primary.__exit__(exc_type, exc_val, exc_tb)
         except GeneratedFile as e:
             if not e.template_path:
@@ -330,11 +380,11 @@ class ControlEditor(object):
             self.changed = _update_control_template(
                 e.template_path, self.path, self.changes())
         except FileNotFoundError:
-            for template_path in [self.path + '.in', self.path + '.m4']:
-                if os.path.exists(template_path):
-                    self.changed = _update_control_template(
-                        template_path, self.path, self.changes())
-                    break
+            template_path = _find_template_path(self.path)
+            if template_path:
+                self.changed = _update_control_template(
+                    template_path, self.path, self.changes(),
+                    expand_template=not self._template_only)
             else:
                 raise
         else:
@@ -343,7 +393,8 @@ class ControlEditor(object):
 
     def add_binary(self, contents):
         if isinstance(contents, dict):
-            para = Deb822(contents)
+            para = new_deb822_paragraph()
+            para.update(contents)
         else:
             para = contents
         return self._primary.paragraphs.append(para)
