@@ -23,19 +23,66 @@ __all__ = [
     'reformat_deb822',
     'ChangeConflict',
     'Deb822Editor',
+    'new_deb822_paragraph',
+    'parse_deb822_file',
+    'parse_deb822_paragraph',
+    'Deb822Paragraph',
     ]
 
 from io import BytesIO
 from typing import Iterable, List, Optional
 
-from debian.deb822 import Deb822
+from debian.changelog import Version
+
+try:
+    from debian import __version__ as python_debian_version
+    parsed_python_debian_version = Version(python_debian_version)
+    # Disabled until bug 996785 is fixed.
+    raise ModuleNotFoundError
+    if parsed_python_debian_version < Version('0.1.42+git20211123'):
+        raise ModuleNotFoundError
+    try:
+        from debian._deb822_repro.parsing import (
+            parse_deb822_file,
+            Deb822ParagraphElement as Deb822Paragraph,
+            Deb822FileElement as Deb822File,
+            )
+    except TypeError:
+        # This happens on python 3.7 with older versions of python3-debian
+        raise ModuleNotFoundError
+    if parse_deb822_file is None:
+        # On python < 3.9, this is the case
+        raise ModuleNotFoundError
+
+    def parse_deb822_paragraph(p):
+        f = parse_deb822_file(p)
+        [p] = f.iter_parts_of_type(Deb822Paragraph)
+        return p
+
+    def new_deb822_paragraph():
+        return Deb822Paragraph.new_empty_paragraph()
+
+    has_deb822_repro = True
+except ModuleNotFoundError:
+    from debian.deb822 import Deb822
+
+    def parse_deb822_file(c):  # type: ignore
+        return list(Deb822.iter_paragraphs(c))
+
+    Deb822Paragraph = Deb822  # type: ignore
+    Deb822File = Iterable[Deb822Paragraph]  # type: ignore
+    parse_deb822_paragraph = Deb822
+    new_deb822_paragraph = Deb822
+
+    has_deb822_repro = False
+
 
 from .reformatting import (
     Editor,
     )
 
 
-def dump_paragraphs(paragraphs: Iterable[Deb822]) -> bytes:
+def dump_paragraphs(paragraphs: Deb822File) -> bytes:
     """Dump a set of deb822 paragraphs to a file.
 
     Args:
@@ -44,13 +91,17 @@ def dump_paragraphs(paragraphs: Iterable[Deb822]) -> bytes:
       formatted text (as bytes)
     """
     outf = BytesIO()
-    first = True
-    for paragraph in paragraphs:
-        if paragraph:
-            if not first:
-                outf.write(b'\n')
-            paragraph.dump(fd=outf, encoding='utf-8')
-            first = False
+    if hasattr(paragraphs, 'dump'):
+        # deb822_repro
+        paragraphs.dump(outf)
+    else:
+        first = True
+        for paragraph in paragraphs:
+            if paragraph:
+                if not first:
+                    outf.write(b'\n')
+                paragraph.dump(fd=outf)
+                first = False
     return outf.getvalue()
 
 
@@ -62,8 +113,7 @@ def reformat_deb822(contents: bytes) -> bytes:
     Returns:
       New contents
     """
-    return dump_paragraphs(
-        Deb822.iter_paragraphs(BytesIO(contents), encoding='utf-8'))
+    return dump_paragraphs(parse_deb822_file(BytesIO(contents)))
 
 
 class ChangeConflict(Exception):
@@ -122,7 +172,8 @@ class Deb822Editor(Editor):
 
         changes = dict(changes.items())
         for paragraph in self.paragraphs:
-            for item in paragraph.items():
+            for item_ in list(paragraph.items()):
+                item = (str(item_[0]), str(item_[1]))
                 for key, old_value, new_value in changes.pop(item, []):
                     if paragraph.get(key) != old_value:
                         new_value = resolve_conflict(
@@ -134,7 +185,7 @@ class Deb822Editor(Editor):
                         paragraph[key] = new_value
         # Add any new paragraphs that weren't processed earlier
         for key, p in changes.items():
-            paragraph = Deb822()
+            paragraph = new_deb822_paragraph()
             for (field, old_value, new_value) in p:
                 if old_value is not None:
                     new_value = resolve_conflict(
@@ -145,10 +196,10 @@ class Deb822Editor(Editor):
             self.paragraphs.append(paragraph)
 
     def _parse(self, content):
-        return list(Deb822.iter_paragraphs(content, encoding='utf-8'))
+        return parse_deb822_file(content.splitlines(True))
 
     @property
-    def paragraphs(self) -> List[Deb822]:
+    def paragraphs(self) -> List[Deb822Paragraph]:
         return self._parsed
 
     def _format(self, paragraphs):
@@ -156,5 +207,5 @@ class Deb822Editor(Editor):
 
     def _nonexistant(self):
         if self.allow_missing:
-            return [Deb822()]
+            return parse_deb822_file([])
         raise
