@@ -59,9 +59,14 @@ class TestCaseInTempDir(TestCase):
                 with open(entry[0], 'w') as f:
                     f.write(entry[1])
 
-    def assertFileEqual(self, content, path):
+    def assertFileEqual(
+            self, expected_content, path, strip_trailing_whitespace=False):
         with open(path, 'r') as f:
-            self.assertEqual(content, f.read())
+            content = f.read()
+        if strip_trailing_whitespace:
+            content = content.rstrip()
+            expected_content = expected_content.rstrip()
+        self.assertEqual(expected_content, content)
 
 
 def test_suite():
