@@ -84,7 +84,7 @@ blah (1.0-1) UNRELEASED; urgency=unknown
                 package='blah',
                 urgency='low',
                 maintainer=('Jelmer Vernooij', 'jelmer@debian.org'),
-                timestamp=datetime.fromtimestamp(1604934305))
+                timestamp=datetime.utcfromtimestamp(1604934305))
 
         with open('debian/changelog', 'r') as f:
             self.assertEqual("""\
@@ -127,7 +127,7 @@ lintian-brush (0.29) UNRELEASED; urgency=medium
         with ChangelogEditor() as updater:
             updater.auto_version(
                 Version('0.29'),
-                timestamp=datetime.fromtimestamp(1604934305))
+                timestamp=datetime.utcfromtimestamp(1604934305))
         with open('debian/changelog', 'r') as f:
             self.assertEqual("""\
 lintian-brush (0.29) UNRELEASED; urgency=medium
@@ -151,7 +151,7 @@ lintian-brush (0.28) unstable; urgency=medium
             updater.auto_version(
                 Version('0.29'),
                 maintainer=('Jelmer Vernooij', 'jelmer@debian.org'),
-                timestamp=datetime.fromtimestamp(1604934305))
+                timestamp=datetime.utcfromtimestamp(1604934305))
         with open('debian/changelog', 'r') as f:
             self.assertEqual("""\
 lintian-brush (0.29) UNRELEASED; urgency=low
@@ -171,6 +171,34 @@ lalalalala
 """)
         self.assertRaises(ChangelogCreateError, ChangelogEditor().__enter__)
 
+    def test_add_entry_to_new_block(self):
+        with ChangelogEditor.create() as updater:
+            updater[-1].distributions = 'unstable'
+            updater.auto_version(
+                Version('2.0-1'),
+                package='blah',
+                urgency='low',
+                maintainer=('Jelmer Vernooij', 'jelmer@debian.org'),
+                timestamp=datetime.utcfromtimestamp(1604934305))
+            updater.add_entry(
+                ['New release'],
+                maintainer=('Jelmer Vernooij', 'jelmer@debian.org'))
+
+        with open('debian/changelog', 'r') as f:
+            self.assertEqual("""\
+blah (2.0-1) UNRELEASED; urgency=low
+
+  * New release
+
+ -- Jelmer Vernooij <jelmer@debian.org>  Mon, 09 Nov 2020 15:05:05 -0000
+
+lintian-brush (0.28) unstable; urgency=medium
+
+  * Add fixer for obsolete-runtime-tests-restriction.
+
+ -- Jelmer Vernooij <jelmer@debian.org>  Mon, 02 Sep 2019 00:23:11 +0000
+""", f.read())
+
 
 class TextWrapperTests(TestCase):
 
@@ -324,27 +352,27 @@ class StripChangelogMessageTests(TestCase):
 class TestNewUpstreamPackageVersion(TestCase):
 
     def test_simple_debian(self):
-        self.assertEquals(
+        self.assertEqual(
             Version("1.2-1"),
             new_upstream_package_version("1.2", "debian"))
 
     def test_simple_ubuntu(self):
-        self.assertEquals(
+        self.assertEqual(
             Version("1.2-0ubuntu1"),
             new_upstream_package_version("1.2", "ubuntu"))
 
     def test_debian_with_dash(self):
-        self.assertEquals(
+        self.assertEqual(
             Version("1.2-0ubuntu1-1"),
             new_upstream_package_version("1.2-0ubuntu1", "debian"))
 
     def test_ubuntu_with_dash(self):
-        self.assertEquals(
+        self.assertEqual(
             Version("1.2-1-0ubuntu1"),
             new_upstream_package_version("1.2-1", "ubuntu"))
 
     def test_ubuntu_with_epoch(self):
-        self.assertEquals(
+        self.assertEqual(
             Version("3:1.2-1-0ubuntu1"),
             new_upstream_package_version("1.2-1", "ubuntu", "3"))
 
@@ -514,20 +542,20 @@ class FindLastDistributionTests(TestCase):
 
     def test_first(self):
         changelog = self.create_changelog("unstable")
-        self.assertEquals("unstable", find_last_distribution(changelog))
+        self.assertEqual("unstable", find_last_distribution(changelog))
 
     def test_second(self):
         changelog = self.create_changelog("unstable", "UNRELEASED")
-        self.assertEquals("UNRELEASED", changelog.distributions)
-        self.assertEquals("unstable", find_last_distribution(changelog))
+        self.assertEqual("UNRELEASED", changelog.distributions)
+        self.assertEqual("unstable", find_last_distribution(changelog))
 
     def test_empty(self):
         changelog = self.create_changelog()
-        self.assertEquals(None, find_last_distribution(changelog))
+        self.assertEqual(None, find_last_distribution(changelog))
 
     def test_only_unreleased(self):
         changelog = self.create_changelog("UNRELEASED")
-        self.assertEquals(None, find_last_distribution(changelog))
+        self.assertEqual(None, find_last_distribution(changelog))
 
 
 class ChangelogInfoTests(TestCase):
@@ -604,21 +632,21 @@ class ChangelogInfoTests(TestCase):
 class UpstreamMergeChangelogLineTests(TestCase):
 
     def test_release(self):
-        self.assertEquals(
+        self.assertEqual(
             "New upstream release.",
             upstream_merge_changelog_line("1.0"))
 
     def test_bzr_snapshot(self):
-        self.assertEquals(
+        self.assertEqual(
             "New upstream snapshot.",
             upstream_merge_changelog_line("1.0+bzr3"))
 
     def test_git_snapshot(self):
-        self.assertEquals(
+        self.assertEqual(
             "New upstream snapshot.",
             upstream_merge_changelog_line("1.0~git20101212"))
 
     def test_plus(self):
-        self.assertEquals(
+        self.assertEqual(
             "New upstream release.",
             upstream_merge_changelog_line("1.0+dfsg1"))
