@@ -214,6 +214,21 @@ opts=uversionmangle=tr/+/~/ \\
         self.assertEqual(
             '1.0~alpha1', wf.entries[0].uversionmangle('1.0+alpha1'))
 
+    def test_parse_y_expr(self):
+        wf = parse_watch_file(StringIO("""\
+version = 3
+opts=uversionmangle=y/+/~/ \\
+   https://samba.org/~jelmer/ blah-(\\d+).tar.gz
+"""))
+        self.assertEqual(3, wf.version)
+        try:
+            import tr  # noqa: F401
+        except ModuleNotFoundError:
+            self.skipTest('tr module not available')
+        self.assertEqual('1.0', wf.entries[0].uversionmangle('1.0'))
+        self.assertEqual(
+            '1.0~alpha1', wf.entries[0].uversionmangle('1.0+alpha1'))
+
     def test_parse_subst_expr_escape(self):
         wf = parse_watch_file(StringIO("""\
 version = 3
